==> spip_4.1.9+dfsg.orig.tar.xz: plugins-dist/sites/lang/sites_km.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=km
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_echec_syndication_01' => 'បញ្ជាប់ ត្រូវបានបរាជ័យ៖ ផ្នែក​ខាង​ចុង​ដែល​បាន​ជ្រើសរើស​មិន​អាច​អាន​បាន​ឬ​ក៏​វា​មិន​ផ្ដល់​អត្ថបទ​ណាមួយ​ឡើយ ។',
	'avis_echec_syndication_02' => 'បញ្ជាប់ ត្រូវបានបរាជ័យ៖ មិន​អាច ចូលទៅ​ផ្នែក​ខាង​ចុង​នៃ​វ៉ែបសៃថ៍ ​នេះ។',
	'avis_site_introuvable' => 'គ្មានរកឃើញ វ៉ែបសៃថ៍',
	'avis_site_syndique_probleme' => 'ប្រយត្ន ៖ បញ្ជាប់ នៃសៃថ៍នេះ បានជួបបញ្ហា; ចឹង ប្រព័ន្ធ ត្រូវបានផ្អាក បណ្តោះអាសន្ន។ ផ្ទៀងអាសយដ្ឋាន នៃឯកសារបញ្ជាប់ នៃសៃថ៍នេះ (<b>@url_syndic@</b>) និងព្យាយាមសង្គ្រោះឡើងវិញ ពត៌មាន។',
	'avis_sites_probleme_syndication' => 'វ៉ែបសៃថ៍​ទាំងនេះ ​បានប្រទះ មួយបញ្ហាបញ្ជាប់',
	'avis_sites_syndiques_probleme' => 'វ៉ែបសៃថ៍បញ្ជាប់ទាំងនេះ បានមានបញ្ហា',

	// B
	'bouton_radio_modere_posteriori' => 'សំរបសំរួល ពេលបន្ទាប់', # MODIF
	'bouton_radio_modere_priori' => 'សំរបសំរួល ជាដំបូង', # MODIF
	'bouton_radio_non_syndication' => 'គ្មានបញ្ជាប់',
	'bouton_radio_syndication' => 'ការបញ្ជាប់​គ្នា ៖',

	// E
	'entree_adresse_fichier_syndication' => 'អា​សយ​ដ្ឋាន នៃសំណុំឯកសារបញ្ជាប់ ៖',
	'entree_adresse_site' => '<b>អាសយដ្ឋាន នៃសៃថ៍</b> [តំរូវ អោយ​ដាក់]',
	'entree_description_site' => 'ការពិពណ៌នា នៃសៃថ៍',

	// F
	'form_prop_nom_site' => 'ឈ្មោះវ៉ែបសៃថ៍',

	// I
	'icone_modifier_site' => 'កែប្រែ សៃថ៍នេះ',
	'icone_referencer_nouveau_site' => 'យោង មួយសៃថ៍ថ្មី',
	'icone_voir_sites_references' => 'មើល រាល់សៃថ៍យោង',
	'info_1_site' => '១ សៃថ៍',
	'info_a_valider' => '[​ត្រូវធ្វើ​អោយ​សុពលភាព​]',
	'info_bloquer' => 'រារាំង',
	'info_bloquer_lien' => 'រាំងខ្ទប់ តំណភ្ជាប់នេះ',
	'info_derniere_syndication' => 'បញ្ជាប់ចុងក្រោយ នៃសៃថ៍នេះ ត្រូវបានអនុវត្ត',
	'info_liens_syndiques_1' => 'តំណភ្ជាប់ ត្រូវបានភ្ជាប់',
	'info_liens_syndiques_2' => 'ការ​រង់ចាំ​ការ​បញ្ជាក់',
	'info_nom_site_2' => '<b>ឈ្មោះសៃថ៍</b> [តំរូវ អោយដាក់]',
	'info_panne_site_syndique' => 'វ៉ែបសៃថ៍ ​ដែល​បាន​ផ្សព្វផ្សាយ​ ខូច',
	'info_probleme_grave' => 'បញ្ហា ​នៃ',
	'info_question_proposer_site' => 'អ្នកណា អាចស្នើ សៃថ៍យោង?',
	'info_retablir_lien' => 'ស្ដារ​ឡើងវិញ តំណភ្ជាប់នេះ',
	'info_site_attente' => 'វ៉ែបសៃថ៍ រង់ចាំ​សុពលភាព',
	'info_site_propose' => 'បានស្នើ សៃថ៍ ៖',
	'info_site_reference' => 'វ៉ែបសៃថ៍យោង លើអិនរើណែត',
	'info_site_refuse' => '​បាន​បដិសេធ វ៉ែបសៃថ៍',
	'info_site_syndique' => 'សៃថ៍នេះ​ ត្រូវ​បានបញ្ជាប់...', # MODIF
	'info_site_valider' => '​​សៃថ៍ ដែល​ត្រូវធ្វើអោយសុពលភាព',
	'info_sites_referencer' => 'យោង​ មួយវ៉ែបសៃថ៍',
	'info_sites_refuses' => 'សៃថ៍ ​ដែល​បានត្រូវ​​បដិសេធ',
	'info_statut_site_1' => 'សៃថ៍នេះ​ គឺ ៖',
	'info_statut_site_2' => 'បានត្រូវ​​ផ្សព្វផ្សាយ',
	'info_statut_site_3' => 'បាន​ត្រូវ​ស្នើ',
	'info_statut_site_4' => 'នៅ​ធុងសំរាម', # MODIF
	'info_syndication' => 'ការ​បញ្ជាប់​គ្នា ៖',
	'info_syndication_articles' => 'អត្ថបទ ៖',
	'item_bloquer_liens_syndiques' => 'បញ្ឈប់​ទំនាក់ទំនង​ដែល​ត្រូវ​បាន​បញ្ចូល​ដើម្បី​ផ្ដល់​សុពលភាព',
	'item_gerer_annuaire_site_web' => 'គ្រប់គ្រង​បញ្ជី (directory) របស់​វ៉ិ​ប​សាយ',
	'item_non_bloquer_liens_syndiques' => 'មិន​បញ្ឈប់​ទំនាក់ទំនង​មក​ពី​ការ​បញ្ចូល (syndication)',
	'item_non_gerer_annuaire_site_web' => 'បិទមុខ​ងារ​បញ្ជ (directory) របស់​វ​វ៉ិ​ប​សាយ',
	'item_non_utiliser_syndication' => 'មិន​ប្រើប្រាស់​ការ​បញ្ចូល​ដោយ​ស្វ័យប្រវត្ដិ',
	'item_utiliser_syndication' => 'ប្រើប្រាស់​ការ​បញ្ចូល​ដោយ​ស្វ័យប្រវត្ដិ',

	// L
	'lien_mise_a_jour_syndication' => 'បន្ទាន់សម័យ ឥឡូវ',
	'lien_nouvelle_recuperation' => 'ព្យាយាម​ដំណើរការ​ការ​សើរើ​ថ្មី​នូវ​ទិន្នន័យ',

	// S
	'syndic_choix_moderation' => 'ត្រូវធ្វើអី សំរាប់តំណភ្ជាប់បន្ទាប់ ចេញពីសៃថ៍នេះ?',
	'syndic_choix_oublier' => 'តើ​ត្រូវធ្វើ​អ្វី​ជាមួយនឹង​ទំនាក់ទំនង​ដែល​លែង​មាននៅ​ក្នុង​ហ្វា​ល​បញ្ចូល (syndication file)?',
	'syndic_choix_resume' => 'មួយចំនួនវ៉ែបសៃថ៍ ផ្សព្វផ្សាយ អត្ថបទពេញលេញ។ ពេលវា មានអត្ថបទពេញលេញ អ្នកចង់ភ្ជាប់វា ឬ?',
	'syndic_lien_obsolete' => 'ទំនាក់ទំនង​លែង​ប្រើ​ការ',
	'syndic_option_miroir' => 'បញ្ឈប់​វា​ដោយ​ស្វ័យប្រវត្ដិ',
	'syndic_option_oubli' => 'លុបសំអាត ពួកវា (​ក្រោយ @mois@ ខែ​)',
	'syndic_option_resume_non' => 'ខ្លឹមសារ​ទាំងស្រុង​នៃ​អត្ថបទ (​ទម្រង់HTML)',
	'syndic_option_resume_oui' => 'គ្រាន់តែ​ជា​សេចក្ដី​សង្ខេប (​ទម្រង់​ជា​អត្ថបទ​)',
	'syndic_options' => 'ជម្រើស​ក្នុង​ការ​បញ្ចូលៈ',

	// T
	'texte_liens_sites_syndiques' => 'ទំនាក់ទំនង​ចេញពី​ហ្វា​ល​ដែល​បាន​បញ្ចូល​អាច​ត្រូវ​កាត់​ផ្ដាច់​ជា​មុន​។ ការ​កំណត់​ខាងក្រោម​បង្ហាញ​នូវ​ការ​កំណត់​ដើម​នៃ​វ៉ិ​ប​សាយ​ដែល​បាន​បញ្ចូល​បន្ទាប់​ពី​ការ​បង្កើត​។ ដូច្នេះ អាច​មានការ​កាត់​ផ្ដាច់​នូវ​ទំនាក់ទំនង​មួយៗ ឬ​ជ្រើសរើស​កាត់​ផ្ដាច់ទំនាក់ទំនង​ចេញពី​វ៉ិ​ប​សាយ​ជាក់លាក់ សំរាប់​វ៉ិ​ប​សាយ​នីមួយៗ​។', # MODIF
	'texte_messages_publics' => 'សារ​សាធារណៈ​នៃ​អត្ថបទ​នេះៈ',
	'texte_non_fonction_referencement' => 'Yលោក​អ្នក​អាច​ជ្រើសរើស​មិន​ប្រេ​ប្រាស់​លក្ខណៈ​ស្វ័យប្រវត្ដិ​នេះ និង​ចូល​ទៅ​ក្នុង​ធាតុ​ដែល​ទាក់ទិន​ទៅ​នឹង​វ៉ិ​ប​សាយ​នេះ​ដោយ​ការ​បញ្ជា​របស់​លោក​អ្នក​....', # MODIF
	'texte_referencement_automatique' => '<b>ការ​យោង​ទៅ​វ៉ិ​ប​សាយ​ដោយ​ស្វ័យប្រវត្ដិ</b><br /> លោក​អ្នក​អាច​យោង​ទៅ​វ៉ិ​ប​សាយ​មួយ​យ៉ាង​រហ័ស ដោយ​ចង្អុល​ខាងក្រោមURL ដែល​ចង់បាន ឬ​អាសយដ្ឋាន​របស់​ហ្វា​ល​បញ្ចូល​នីមួយៗ​។SPIP និង​បង្ហាញ​នូវ​ព័ត៌មាន (​ចំណងជើង ់លក្ខណៈ​....) របស់​វ៉ិ​ប​សាយ​នោះ​ដោយ​ស្វ័យប្រវត្ដិ​។', # MODIF
	'texte_syndication' => 'បើមួយសៃថ៍ អនុញ្ញាត, វាអាចប្រមូលមកវិញ ស្វ័យប្រវត្តិ បញ្ជីនៃសំភារៈចុងក្រោយបំផុត របស់វា។ ដើម្បីសំរេចបានចឹង, អ្នកត្រូវតែធ្វើអោយសកម្ម ការភ្ជាប់។  <blockquote><i>ខំព្យូរើខ្លះ គ្មានអនុញ្ញាត មុខងារនេះ; 
  ក្នុងករណីនេះ, អ្នកគ្មានអាចប្រើប្រាស់ ការភ្ជាប់ខ្លឹមសារ ពីវ៉ែបសៃថ៍ របស់អ្នក។</i></blockquote>', # MODIF
	'titre_articles_syndiques' => 'អត្ថបទ​ដែល​បាន​បញ្ចូល​ត្រូវ​បាន​ទាញ​ចេញពី​វ៉ិ​ប​សាយ​នេះ​។',
	'titre_dernier_article_syndique' => 'អត្ថបទ​ដែល​បាន​បញ្ចូល​ថ្មី​បំផុត',
	'titre_page_sites_tous' => 'ពួកសៃថ៍យោង',
	'titre_referencement_sites' => 'ការយោង នៃសៃថ៍ និងបញ្ជាប់',
	'titre_site_numero' => 'សៃថ៍ លេខ ៖',
	'titre_sites_proposes' => 'ពួកសៃថ៍ ត្រូវបានស្នើ',
	'titre_sites_references_rubrique' => 'រាល់សៃថ៍ យោង ក្នុងផ្នែកនេះ',
	'titre_sites_syndiques' => 'សៃថ៍ ត្រូវបានបញ្ជាប់',
	'titre_sites_tous' => 'រាល់សៃថ៍យោង',
	'titre_syndication' => 'បញ្ជាប់សៃថ៍'
);

==> spip_4.3.8+dfsg.orig.tar.xz: plugins-dist/sites/lang/sites_km.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=km
// ** ne pas modifier le fichier **

return [

	// A
	'avis_echec_syndication_01' => 'បញ្ជាប់ ត្រូវបានបរាជ័យ៖ ផ្នែក​ខាង​ចុង​ដែល​បាន​ជ្រើសរើស​មិន​អាច​អាន​បាន​ឬ​ក៏​វា​មិន​ផ្ដល់​អត្ថបទ​ណាមួយ​ឡើយ ។',
	'avis_echec_syndication_02' => 'បញ្ជាប់ ត្រូវបានបរាជ័យ៖ មិន​អាច ចូលទៅ​ផ្នែក​ខាង​ចុង​នៃ​វ៉ែបសៃថ៍ ​នេះ។',
	'avis_site_introuvable' => 'គ្មានរកឃើញ វ៉ែបសៃថ៍',
	'avis_site_syndique_probleme' => 'ប្រយត្ន ៖ បញ្ជាប់ នៃសៃថ៍នេះ បានជួបបញ្ហា; ចឹង ប្រព័ន្ធ ត្រូវបានផ្អាក បណ្តោះអាសន្ន។ ផ្ទៀងអាសយដ្ឋាន នៃឯកសារបញ្ជាប់ នៃសៃថ៍នេះ (<b>@url_syndic@</b>) និងព្យាយាមសង្គ្រោះឡើងវិញ ពត៌មាន។',
	'avis_sites_probleme_syndication' => 'វ៉ែបសៃថ៍​ទាំងនេះ ​បានប្រទះ មួយបញ្ហាបញ្ជាប់',
	'avis_sites_syndiques_probleme' => 'វ៉ែបសៃថ៍បញ្ជាប់ទាំងនេះ បានមានបញ្ហា',

	// B
	'bouton_radio_modere_posteriori' => 'សំរបសំរួល ពេលបន្ទាប់', # MODIF
	'bouton_radio_modere_priori' => 'សំរបសំរួល ជាដំបូង', # MODIF
	'bouton_radio_non_syndication' => 'គ្មានបញ្ជាប់',
	'bouton_radio_syndication' => 'ការបញ្ជាប់​គ្នា ៖',

	// E
	'entree_adresse_fichier_syndication' => 'អា​សយ​ដ្ឋាន នៃសំណុំឯកសារបញ្ជាប់ ៖',
	'entree_adresse_site' => '<b>អាសយដ្ឋាន នៃសៃថ៍</b> [តំរូវ អោយ​ដាក់]',
	'entree_description_site' => 'ការពិពណ៌នា នៃសៃថ៍',

	// F
	'form_prop_nom_site' => 'ឈ្មោះវ៉ែបសៃថ៍',

	// I
	'icone_modifier_site' => 'កែប្រែ សៃថ៍នេះ',
	'icone_referencer_nouveau_site' => 'យោង មួយសៃថ៍ថ្មី',
	'icone_voir_sites_references' => 'មើល រាល់សៃថ៍យោង',
	'info_1_site' => '១ សៃថ៍',
	'info_a_valider' => '[​ត្រូវធ្វើ​អោយ​សុពលភាព​]',
	'info_bloquer' => 'រារាំង',
	'info_bloquer_lien' => 'រាំងខ្ទប់ តំណភ្ជាប់នេះ',
	'info_derniere_syndication' => 'បញ្ជាប់ចុងក្រោយ នៃសៃថ៍នេះ ត្រូវបានអនុវត្ត',
	'info_liens_syndiques_1' => 'តំណភ្ជាប់ ត្រូវបានភ្ជាប់',
	'info_liens_syndiques_2' => 'ការ​រង់ចាំ​ការ​បញ្ជាក់',
	'info_nom_site_2' => '<b>ឈ្មោះសៃថ៍</b> [តំរូវ អោយដាក់]',
	'info_panne_site_syndique' => 'វ៉ែបសៃថ៍ ​ដែល​បាន​ផ្សព្វផ្សាយ​ ខូច',
	'info_probleme_grave' => 'បញ្ហា ​នៃ',
	'info_question_proposer_site' => 'អ្នកណា អាចស្នើ សៃថ៍យោង?',
	'info_retablir_lien' => 'ស្ដារ​ឡើងវិញ តំណភ្ជាប់នេះ',
	'info_site_attente' => 'វ៉ែបសៃថ៍ រង់ចាំ​សុពលភាព',
	'info_site_propose' => 'បានស្នើ សៃថ៍ ៖',
	'info_site_reference' => 'វ៉ែបសៃថ៍យោង លើអិនរើណែត',
	'info_site_refuse' => '​បាន​បដិសេធ វ៉ែបសៃថ៍',
	'info_site_syndique' => 'សៃថ៍នេះ​ ត្រូវ​បានបញ្ជាប់...', # MODIF
	'info_site_valider' => '​​សៃថ៍ ដែល​ត្រូវធ្វើអោយសុពលភាព',
	'info_sites_referencer' => 'យោង​ មួយវ៉ែបសៃថ៍',
	'info_sites_refuses' => 'សៃថ៍ ​ដែល​បានត្រូវ​​បដិសេធ',
	'info_statut_site_1' => 'សៃថ៍នេះ​ គឺ ៖',
	'info_statut_site_2' => 'បានត្រូវ​​ផ្សព្វផ្សាយ',
	'info_statut_site_3' => 'បាន​ត្រូវ​ស្នើ',
	'info_statut_site_4' => 'នៅ​ធុងសំរាម', # MODIF
	'info_syndication' => 'ការ​បញ្ជាប់​គ្នា ៖',
	'info_syndication_articles' => 'អត្ថបទ ៖',
	'item_bloquer_liens_syndiques' => 'បញ្ឈប់​ទំនាក់ទំនង​ដែល​ត្រូវ​បាន​បញ្ចូល​ដើម្បី​ផ្ដល់​សុពលភាព',
	'item_gerer_annuaire_site_web' => 'គ្រប់គ្រង​បញ្ជី (directory) របស់​វ៉ិ​ប​សាយ',
	'item_non_bloquer_liens_syndiques' => 'មិន​បញ្ឈប់​ទំនាក់ទំនង​មក​ពី​ការ​បញ្ចូល (syndication)',
	'item_non_gerer_annuaire_site_web' => 'បិទមុខ​ងារ​បញ្ជ (directory) របស់​វ​វ៉ិ​ប​សាយ',
	'item_non_utiliser_syndication' => 'មិន​ប្រើប្រាស់​ការ​បញ្ចូល​ដោយ​ស្វ័យប្រវត្ដិ',
	'item_utiliser_syndication' => 'ប្រើប្រាស់​ការ​បញ្ចូល​ដោយ​ស្វ័យប្រវត្ដិ',

	// L
	'lien_mise_a_jour_syndication' => 'បន្ទាន់សម័យ ឥឡូវ',
	'lien_nouvelle_recuperation' => 'ព្យាយាម​ដំណើរការ​ការ​សើរើ​ថ្មី​នូវ​ទិន្នន័យ',

	// S
	'syndic_choix_moderation' => 'ត្រូវធ្វើអី សំរាប់តំណភ្ជាប់បន្ទាប់ ចេញពីសៃថ៍នេះ?',
	'syndic_choix_oublier' => 'តើ​ត្រូវធ្វើ​អ្វី​ជាមួយនឹង​ទំនាក់ទំនង​ដែល​លែង​មាននៅ​ក្នុង​ហ្វា​ល​បញ្ចូល (syndication file)?',
	'syndic_choix_resume' => 'មួយចំនួនវ៉ែបសៃថ៍ ផ្សព្វផ្សាយ អត្ថបទពេញលេញ។ ពេលវា មានអត្ថបទពេញលេញ អ្នកចង់ភ្ជាប់វា ឬ?',
	'syndic_lien_obsolete' => 'ទំនាក់ទំនង​លែង​ប្រើ​ការ',
	'syndic_option_miroir' => 'បញ្ឈប់​វា​ដោយ​ស្វ័យប្រវត្ដិ',
	'syndic_option_oubli' => 'លុបសំអាត ពួកវា (​ក្រោយ @mois@ ខែ​)',
	'syndic_option_resume_non' => 'ខ្លឹមសារ​ទាំងស្រុង​នៃ​អត្ថបទ (​ទម្រង់HTML)',
	'syndic_option_resume_oui' => 'គ្រាន់តែ​ជា​សេចក្ដី​សង្ខេប (​ទម្រង់​ជា​អត្ថបទ​)',
	'syndic_options' => 'ជម្រើស​ក្នុង​ការ​បញ្ចូលៈ',

	// T
	'texte_liens_sites_syndiques' => 'ទំនាក់ទំនង​ចេញពី​ហ្វា​ល​ដែល​បាន​បញ្ចូល​អាច​ត្រូវ​កាត់​ផ្ដាច់​ជា​មុន​។ ការ​កំណត់​ខាងក្រោម​បង្ហាញ​នូវ​ការ​កំណត់​ដើម​នៃ​វ៉ិ​ប​សាយ​ដែល​បាន​បញ្ចូល​បន្ទាប់​ពី​ការ​បង្កើត​។ ដូច្នេះ អាច​មានការ​កាត់​ផ្ដាច់​នូវ​ទំនាក់ទំនង​មួយៗ ឬ​ជ្រើសរើស​កាត់​ផ្ដាច់ទំនាក់ទំនង​ចេញពី​វ៉ិ​ប​សាយ​ជាក់លាក់ សំរាប់​វ៉ិ​ប​សាយ​នីមួយៗ​។', # MODIF
	'texte_messages_publics' => 'សារ​សាធារណៈ​នៃ​អត្ថបទ​នេះៈ',
	'texte_non_fonction_referencement' => 'Yលោក​អ្នក​អាច​ជ្រើសរើស​មិន​ប្រេ​ប្រាស់​លក្ខណៈ​ស្វ័យប្រវត្ដិ​នេះ និង​ចូល​ទៅ​ក្នុង​ធាតុ​ដែល​ទាក់ទិន​ទៅ​នឹង​វ៉ិ​ប​សាយ​នេះ​ដោយ​ការ​បញ្ជា​របស់​លោក​អ្នក​....', # MODIF
	'texte_referencement_automatique' => '<b>ការ​យោង​ទៅ​វ៉ិ​ប​សាយ​ដោយ​ស្វ័យប្រវត្ដិ</b><br /> លោក​អ្នក​អាច​យោង​ទៅ​វ៉ិ​ប​សាយ​មួយ​យ៉ាង​រហ័ស ដោយ​ចង្អុល​ខាងក្រោមURL ដែល​ចង់បាន ឬ​អាសយដ្ឋាន​របស់​ហ្វា​ល​បញ្ចូល​នីមួយៗ​។SPIP និង​បង្ហាញ​នូវ​ព័ត៌មាន (​ចំណងជើង ់លក្ខណៈ​....) របស់​វ៉ិ​ប​សាយ​នោះ​ដោយ​ស្វ័យប្រវត្ដិ​។', # MODIF
	'texte_syndication' => 'បើមួយសៃថ៍ អនុញ្ញាត, វាអាចប្រមូលមកវិញ ស្វ័យប្រវត្តិ បញ្ជីនៃសំភារៈចុងក្រោយបំផុត របស់វា។ ដើម្បីសំរេចបានចឹង, អ្នកត្រូវតែធ្វើអោយសកម្ម ការភ្ជាប់។  <blockquote><i>ខំព្យូរើខ្លះ គ្មានអនុញ្ញាត មុខងារនេះ; 
  ក្នុងករណីនេះ, អ្នកគ្មានអាចប្រើប្រាស់ ការភ្ជាប់ខ្លឹមសារ ពីវ៉ែបសៃថ៍ របស់អ្នក។</i></blockquote>', # MODIF
	'titre_articles_syndiques' => 'អត្ថបទ​ដែល​បាន​បញ្ចូល​ត្រូវ​បាន​ទាញ​ចេញពី​វ៉ិ​ប​សាយ​នេះ​។',
	'titre_dernier_article_syndique' => 'អត្ថបទ​ដែល​បាន​បញ្ចូល​ថ្មី​បំផុត',
	'titre_page_sites_tous' => 'ពួកសៃថ៍យោង',
	'titre_referencement_sites' => 'ការយោង នៃសៃថ៍ និងបញ្ជាប់',
	'titre_site_numero' => 'សៃថ៍ លេខ ៖',
	'titre_sites_proposes' => 'ពួកសៃថ៍ ត្រូវបានស្នើ',
	'titre_sites_references_rubrique' => 'រាល់សៃថ៍ យោង ក្នុងផ្នែកនេះ',
	'titre_sites_syndiques' => 'សៃថ៍ ត្រូវបានបញ្ជាប់',
	'titre_sites_tous' => 'រាល់សៃថ៍យោង',
	'titre_syndication' => 'បញ្ជាប់សៃថ៍',
];
